@@ -2,7 +2,7 @@
 ####**********************************************************************
 ####
 ####  RANDOM FORESTS FOR SURVIVAL, REGRESSION, AND CLASSIFICATION (RF-SRC)
-####  Version 1.4
+####  Version 1.5.4
 ####
 ####  Copyright 2012, University of Miami
 ####
@@ -62,13 +62,16 @@
 
 stat.split.rfsrc <- function(object, ...)
 {
+  if (sum(inherits(object, c("rfsrc", "synthetic"), TRUE) == c(1, 2)) == 2) {
+    object <- object$rfSyn
+  }
   if (is.null(object)) stop("Object is empty!")
   if ((sum(inherits(object, c("rfsrc", "grow"), TRUE) == c(1, 2)) != 2) &&
       (sum(inherits(object, c("rfsrc", "predict"), TRUE) == c(1, 2)) != 2))
     stop("This function only works for objects of class `(rfsrc, grow)' or `(rfsrc, pred)',")
   inbag <- object$inbag
   if (is.null(object$node.stats)) {    
-    stop("RFSRC statistics content is NULL.  Please re-run call with statistics set to 'TRUE'.")
+    stop("RFSRC statistics content is NULL.  Please re-run grow call with 'statistics=TRUE'")
   }
   else {
     extendedNativeArray <- object$node.stats
